#
# This file is autogenerated by pip-compile with Python 3.10
# by the following command:
#
#    pip-compile --output-file=scargo/file_generators/templates/docker/requirements.txt.j2 pyproject.toml
#
bcrypt==4.2.0
    # via paramiko
bitarray==2.9.2
    # via bitstring
bitstring==4.2.3
    # via esptool
certifi==2024.8.30
    # via requests
cffi==1.17.1
    # via
    #   cryptography
    #   pynacl
charset-normalizer==3.3.2
    # via requests
clang==17.0.6
    # via scargo (pyproject.toml)
click==8.1.3
    # via
    #   scargo (pyproject.toml)
    #   typer
cmake==3.30.5
    # via scargo (pyproject.toml)
colorama==0.4.6
    # via conan
coloredlogs==15.0.1
    # via scargo (pyproject.toml)
colorlog==6.9.0
    # via gcovr
conan==2.8.1
    # via scargo (pyproject.toml)
cryptography==41.0.7
    # via
    #   esptool
    #   paramiko
distro==1.8.0
    # via conan
docker==7.1.0
    # via scargo (pyproject.toml)
ecdsa==0.19.0
    # via esptool
esptool==4.7.0
    # via scargo (pyproject.toml)
fasteners==0.19
    # via conan
gcovr==8.2
    # via scargo (pyproject.toml)
humanfriendly==10.0
    # via coloredlogs
idna==3.10
    # via requests
intelhex==2.3.0
    # via esptool
jinja2==3.1.4
    # via
    #   conan
    #   gcovr
    #   scargo (pyproject.toml)
libclang==18.1.1
    # via scargo (pyproject.toml)
lizard==1.17.10
    # via scargo (pyproject.toml)
lxml==5.4.0
    # via gcovr
markupsafe==2.1.5
    # via jinja2
paramiko==3.5.0
    # via scargo (pyproject.toml)
patch-ng==1.18.0
    # via conan
pycparser==2.22
    # via cffi
pydantic==1.10.6
    # via scargo (pyproject.toml)
pygments==2.18.0
    # via gcovr
pynacl==1.5.0
    # via paramiko
pyserial==3.5
    # via esptool
python-dateutil==2.9.0.post0
    # via conan
pyyaml==6.0.2
    # via
    #   conan
    #   esptool
    #   scargo (pyproject.toml)
reedsolo==1.6.0
    # via esptool
requests==2.32.3
    # via
    #   conan
    #   docker
six==1.16.0
    # via
    #   ecdsa
    #   python-dateutil
toml==0.10.2
    # via scargo (pyproject.toml)
tomli==2.2.1
    # via gcovr
tomlkit==0.13.2
    # via scargo (pyproject.toml)
typer==0.9.0
    # via scargo (pyproject.toml)
typing-extensions==4.6.0
    # via
    #   pydantic
    #   scargo (pyproject.toml)
    #   typer
urllib3==1.26.20
    # via
    #   conan
    #   docker
    #   requests
